@@ -1,4 +1,4 @@
-/* window-menu.c: Window Menu applet
+/* window-menu.c: Window Selector applet
  *
  * Copyright (C) 2003 Sun Microsystems, Inc.
  * Copyright (C) 2001 Free Software Foundation, Inc.
@@ -40,7 +40,6 @@
 
 #include "inlinepixbufs.h"
 #include "eel/eel-ellipsizing-label.h"
-#include "egg-screen-help.h"
 #include "wncklet.h"
 
 typedef struct {
@@ -50,6 +49,7 @@ typedef struct {
 	GtkWidget    *image;
 	GtkWidget    *menu;
 	GtkWidget    *no_windows_item;
+	GtkWidget    *about_dialog;
 
 	GdkPixbuf    *icon_pixbuf;
 	WnckWindow   *icon_window;
@@ -70,8 +70,8 @@ window_menu_help (BonoboUIComponent *uic,
 {
 	GError *error = NULL;
 
-	egg_help_display_desktop_on_screen (
-		NULL, "window-menu", "window-menu", NULL,
+	gnome_help_display_desktop_on_screen (
+		NULL, "user-guide", "user-guide.xml", "gosmetacity-27",
 		gtk_widget_get_screen (window_menu->applet),
 		&error);
 
@@ -109,17 +109,19 @@ window_menu_about (BonoboUIComponent *uic,
 		"Jacob Berkman <jacob@helixcode.com>",
 		NULL
 	};
-	const char *documenters [] = { NULL };
+	const char *documenters [] = { 
+                "Sun GNOME Documentation Team <gdocteam@sun.com>",
+                NULL 
+        };
 	const char *translator_credits = _("translator_credits");
 
-	static GtkWidget *about = NULL;
 	GdkPixbuf        *pixbuf = NULL;
 	char             *file;
 
-	if (about) {
-		gtk_window_set_screen (GTK_WINDOW (about),
+	if (window_menu->about_dialog) {
+		gtk_window_set_screen (GTK_WINDOW (window_menu->about_dialog),
 				       gtk_widget_get_screen (window_menu->applet));
-		gtk_window_present (GTK_WINDOW (about));
+		gtk_window_present (GTK_WINDOW (window_menu->about_dialog));
 		return;
 	}
 
@@ -129,28 +131,28 @@ window_menu_about (BonoboUIComponent *uic,
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	g_free (file);
 
-	about = gnome_about_new (_("Window Menu"), VERSION,
+	window_menu->about_dialog = gnome_about_new (_("Window Selector"), VERSION,
 				 "Copyright \xc2\xa9 2003 Sun Microsystems, Inc.\n"
 				 "Copyright \xc2\xa9 2001 Free Software Foundation, Inc.\n"
 				 "Copyright \xc2\xa9 2000 Helix Code, Inc.",
-				 _("The Window Menu shows a list of all windows and lets you browse them."),
+				 _("The Window Selector shows a list of all windows and lets you browse them."),
 				 authors,
 				 documenters,
 				 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 				 pixbuf);
 
-	gtk_window_set_wmclass (GTK_WINDOW (about), "window-menu", "WindowMenu");
-	gtk_window_set_screen (GTK_WINDOW (about),
+	gtk_window_set_wmclass (GTK_WINDOW (window_menu->about_dialog), "window-menu", "WindowMenu");
+	gtk_window_set_screen (GTK_WINDOW (window_menu->about_dialog),
 			       gtk_widget_get_screen (window_menu->applet));
 
 	if (pixbuf) {
-		gtk_window_set_icon (GTK_WINDOW (about), pixbuf);
+		gtk_window_set_icon (GTK_WINDOW (window_menu->about_dialog), pixbuf);
 		g_object_unref (pixbuf);
 	}
 
-	g_signal_connect (about, "destroy",
-			  (GCallback) gtk_widget_destroyed, &about);
-	gtk_widget_show (about);
+	g_signal_connect (window_menu->about_dialog, "destroy",
+			  (GCallback) gtk_widget_destroyed, &window_menu->about_dialog);
+	gtk_widget_show (window_menu->about_dialog);
 }
 
 static const BonoboUIVerb window_menu_verbs [] =
@@ -180,6 +182,11 @@ window_menu_destroy (GtkWidget  *widget,
 		g_object_unref (window_menu->no_windows_item);
 	window_menu->no_windows_item = NULL;
 
+	if (window_menu->about_dialog) {
+		gtk_widget_destroy (window_menu->about_dialog);
+		window_menu->about_dialog = NULL;
+	}
+
 	g_free (window_menu);
 }
 
@@ -698,7 +705,7 @@ window_menu_applet_fill (PanelApplet *applet)
 
 	window_menu->applet = GTK_WIDGET (applet);
 	atk_obj = gtk_widget_get_accessible (window_menu->applet);
-	atk_object_set_name (atk_obj, _("Window Menu"));
+	atk_object_set_name (atk_obj, _("Window Selector"));
 	atk_object_set_description (atk_obj, _("Tool to switch between windows"));
 
 	panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
